==> opennms-model-1.13.5-20140825.090004-25-sources.jar: org/opennms/netmgt/model/OnmsGroupList.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2011-2012 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2012 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.model;

import java.util.Collection;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.opennms.core.config.api.JaxbListWrapper;

@XmlRootElement(name="groups")
@XmlAccessorType(XmlAccessType.NONE)
public class OnmsGroupList extends JaxbListWrapper<OnmsGroup> {
    private static final long serialVersionUID = 1L;

    public OnmsGroupList() { super(); }
    public OnmsGroupList(final Collection<? extends OnmsGroup> groups) {
        super(groups);
    }

    @XmlElement(name="group")
    public List<OnmsGroup> getObjects() {
        return super.getObjects();
    }
    public List<OnmsGroup> getGroups() {
        return getObjects();
    }
    public void setGroups(final List<OnmsGroup> groups) {
        setObjects(groups);
    }
}

==> opennms-model-22.0.0-20180129.132414-77-sources.jar: org/opennms/netmgt/model/OnmsGroupList.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2011-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.model;

import java.util.Collection;
import java.util.List;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

import org.codehaus.jackson.annotate.JsonProperty;
import org.codehaus.jackson.map.annotate.JsonRootName;
import org.opennms.core.config.api.JaxbListWrapper;

@XmlRootElement(name="groups")
@XmlAccessorType(XmlAccessType.NONE)
@JsonRootName("groups")
public class OnmsGroupList extends JaxbListWrapper<OnmsGroup> {
    private static final long serialVersionUID = 1L;

    public OnmsGroupList() { super(); }
    public OnmsGroupList(final Collection<? extends OnmsGroup> groups) {
        super(groups);
    }

    @XmlElement(name="group")
    @JsonProperty("group")
    public List<OnmsGroup> getObjects() {
        return super.getObjects();
    }

    public List<OnmsGroup> getGroups() {
        return getObjects();
    }

    public void setGroups(final List<OnmsGroup> groups) {
        setObjects(groups);
    }
}
